AesCbcCryptor class

AesCbcCryptor is new and enhanced cryptor to encrypt/decrypt PubNub messages. It's always preferred to use this cryptor instead old cryptor.

Constructors

AesCbcCryptor(CipherKey cipherKey)

Properties

cipherKey ↔ CipherKey
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(EncryptedData encryptedData) → List<int>
decryptFileData(EncryptedData input) → List<int>
encrypt(List<int> input) → EncryptedData
encryptFileData(List<int> input) → EncryptedData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited