LegacyCryptor class

Legacy cryptor exists so that SDK will be able to decrypt old contents which were encrypted in the past.

It uses AES-CBC with a key derived by SHA-256 and, by default, a random IV. For new applications prefer AesCbcCryptor, which is the enhanced, recommended cryptor.

Annotations
  • @Deprecated('Use AesCbcCryptor for new applications. LegacyCryptor is retained only ' 'to decrypt content encrypted by older SDK versions and will be removed ' 'in a future release.')

Constructors

LegacyCryptor(CipherKey cipherKey, {CryptoConfiguration cryptoConfiguration = const CryptoConfiguration()})

Properties

cipherKey CipherKey
final
cryptoConfiguration CryptoConfiguration
final
cryptor ↔ LegacyCryptoModule
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(EncryptedData input) List<int>
decryptFileData(EncryptedData input) List<int>
encrypt(List<int> input) → EncryptedData
encryptFileData(List<int> input) → EncryptedData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited