Level class abstract

Represents the level of a log record.

Those are not strict. How (and if) they work depends on the implementation of the logger.

Constructors

Level()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

all → int
Intended to enable all logging.
final
fatal → int
Intended for fatal errors that end in application crash or exit.
final
fine → int
Intended for the fine mode.
final
info → int
Intended for informational messages.
final
levels → Map<int, String>
final
off → int
Intended to disable logging at all.
final
severe → int
Intended for severe exceptions that need to be resolved.
final
shout → int
Intended for an extra debug information. Only use when debugging.
final
silly → int
Intended for the super verbose mode.
final
verbose → int
Intended for the verbose mode.
final
warning → int
Intended for warnings.
final

Static Methods

getName(int level) → String