LogRecord class

A record that contains logged information.

Constructors

LogRecord({required int level, required dynamic message, required String scope, StackTrace? stackTrace})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
final
level → int
Level of this log record.
final
message → dynamic
Message passed to the log method.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
Scope of this.
final
stackTrace → StackTrace?
Stack trace recorded when this record was created.
final
time → DateTime
Time at which this record was created.
final
zone → Zone
Zone of the calling code.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultPrinter ↔ void Function(LogRecord)
Function that can be passed into listen method to print a LogRecord.
getter/setter pair

Static Methods

createPrinter(String format, {dynamic customPrint(String s) = print}) → void Function(LogRecord)
Returns a function that accepts a LogRecord and prints it using customPrint in given format.