NetworkingModule class

Constructors

NetworkingModule({RetryPolicy? retryPolicy, String? origin, bool? ssl, bool? enableHttp2})

Properties

enableHttp2 → bool
Whether to negotiate HTTP/2 (with automatic HTTP/1.1 fallback) on the native (dart:io) transport.
final
hashCode → int
The hash code for this object.
no setterinherited
origin → String?
Origin used for all requests.
final
retryPolicy ↔ RetryPolicy?
Retry policy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssl → bool
Whether https or http should be used.
final

Methods

dispose() → void
Releases any transport resources held by this module.
getOrigin() → Uri
handler() → Future<IRequestHandler>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Core core) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited