ChannelOccupancy class Results

Represents current channel participants.

Constructors

ChannelOccupancy(String channelName, Map<String, OccupantInfo> uuids, int count)
ChannelOccupancy.fromJson(String channelName, Map<String, dynamic> channelObject)
factory

Properties

channelName ↔ String
getter/setter pair
count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuids ↔ Map<String, OccupantInfo>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited