KeysetStore class

Represents a collection of Keyset.

Keyset names must be unique and only one of them can be default.

Constructors

KeysetStore()

Properties

defaultKeyset → Keyset
Default keyset.
no setter
hashCode → int
The hash code for this object.
no setterinherited
keysets → List<Keyset>
Returns a list of all keysets in this store.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(String name, Keyset keyset, {bool useAsDefault = false}) → Keyset
Adds a keyset named name to the store.
forEach(void callback(String, Keyset)) → void
Iterate over each keyset.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String name) → Keyset?
Removes a keyset from this store.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String? name) → Keyset
Gets a defined keyset.