PaginatedChannelHistory class

Represents readonly history of messages in a channel.

It fetches messages in chunks only when requested using more call.

Properties

chunkSize → int
Maximum number of fetched messages when calling more.
no setter
endTimetoken → Timetoken?
Upper bound of fetched messages timetokens. Readonly.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
Returns true if there are more messages to be fetched.
no setter
messages → List<BaseMessage>
Readonly list of messages. It will be empty before first more call.
no setter
order → ChannelHistoryOrder
Order in which messages are fetched.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimetoken → Timetoken?
Lower bound of fetched messages timetokens. Readonly.
no setter

Methods

more() → Future<FetchHistoryResult>
Fetches more messages and stores them in messages.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Resets the history to the beginning.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited