UuidMetadataInput class Objects

Represents UUID metadata operations input.

Constructors

UuidMetadataInput({String? name, String? email, String? externalId, String? profileUrl, Map<String, Object?>? custom, String? status, String? type})

Properties

custom ↔ Map<String, Object?>?
getter/setter pair
email ↔ String?
getter/setter pair
externalId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
profileUrl ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited